"""
Extra package

"""

from .municipality import Municipality

__all__ = ("Municipality",)
